@@ -6,7 +6,7 @@ from collections import namedtuple
 import numpy as np
 
 from numpy import min, max, median, std, isnan, delete, genfromtxt, savetxt, load, \
-    asarray, add, append, log10, average, array
+    asarray, add, append, log10, average, array, where
 from astropy.units import degree, arcsecond
 from astropy.coordinates import SkyCoord
 from astroquery.sdss import SDSS
@@ -22,7 +22,7 @@ import logging
 logger = logging.getLogger('astrosource')
 
 
-def find_comparisons(targets, parentPath=None, fileList=None, stdMultiplier=2.5, thresholdCounts=1000000, variabilityMultiplier=2.5, removeTargets=1, acceptDistance=1.0):
+def find_comparisons(targets, parentPath=None, fileList=None, stdMultiplier=2.5, thresholdCounts=10000000, variabilityMultiplier=2.5, removeTargets=1, acceptDistance=1.0):
     '''
     Find stable comparison stars for the target photometry
 
@@ -207,17 +207,14 @@ def calculate_comparison_variation(compFile, photFileArray, fileCount):
     sortStars=[]
     for cf in compFile:
         compDiffMags = []
-        q=0
         logger.debug("*************************")
         logger.debug("RA : " + str(cf[0]))
         logger.debug("DEC: " + str(cf[1]))
-        for imgs in range(photFileArray.shape[0]):
-            photFile = photFileArray[imgs]
+        for q, photFile in enumerate(photFileArray):
             fileRaDec = SkyCoord(ra=photFile[:,0]*degree, dec=photFile[:,1]*degree)
             matchCoord = SkyCoord(ra=cf[0]*degree, dec=cf[1]*degree)
             idx, d2d, d3d = matchCoord.match_to_catalog_sky(fileRaDec)
             compDiffMags = append(compDiffMags,2.5 * log10(photFile[idx][4]/fileCount[q]))
-            q = add(q,1)
 
         logger.debug("VAR: " +str(std(compDiffMags)))
         stdCompStar.append(std(compDiffMags))
@@ -260,8 +257,9 @@ def remove_stars_targets(parentPath, compFile, acceptDistance, targetFile, remov
     compFile=delete(compFile, idx, axis=0)
     fileRaDec = SkyCoord(ra=compFile[:,0]*degree, dec=compFile[:,1]*degree)
 
+
     # Get Average RA and Dec from file
-    if compFile.shape[0] == 13:
+    if compFile.shape[0] == 13 and compFile.size == 13:
         logger.debug(compFile[0])
         logger.debug(compFile[1])
         avgCoord=SkyCoord(ra=(compFile[0])*degree, dec=(compFile[1]*degree))
@@ -291,7 +289,7 @@ def remove_stars_targets(parentPath, compFile, acceptDistance, targetFile, remov
         catCoords=SkyCoord(ra=compFile[:,0]*degree, dec=compFile[:,1]*degree)
         idxcomp,d2dcomp,d3dcomp=compCoord.match_to_catalog_sky(catCoords)
         logger.debug(d2dcomp)
-        if d2dcomp *arcsecond < max_sep*arcsecond:
+        if d2dcomp.arcsecond.any() < max_sep.value:
             logger.debug("match!")
             varStarReject.append(t)
         else:
@@ -316,28 +314,50 @@ def remove_stars_targets(parentPath, compFile, acceptDistance, targetFile, remov
 
 
 def catalogue_call(avgCoord, opt, cat_name):
-    data = namedtuple(typename='data',field_names=['ra','dec','mag','emag'])
+    data = namedtuple(typename='data',field_names=['ra','dec','mag','emag','cat_name'])
 
-    if cat_name == 'APASS':
-        resp = Vizier.query_region(avgCoord, '0.33 deg', catalog='APASS')['II/336/apass9']
-    elif cat_name == 'SDSS':
-        resp = Vizier.query_region(avgCoord, '0.33 deg', catalog='SDSS')['V/147/sdss12']
-        if not resp:
-            ConeSearch.URL='http://skymapper.anu.edu.au/sm-cone/public/query?'
-            try:
-                resp = ConeSearch.query_region(avgCoord, '0.33 deg')
-            except VOSError:
-                raise AstrosourceException("Could not find RA {} Dec {} in SDSS or SkyMapper".format(avgCoord.ra.value,avgCoord.dec.value))
-    elif cat_name == 'PanSTARRS':
-        resp = Vizier.query_region(avgCoord, '0.33 deg', catalog='PanStarrs')['II/349/ps1']
+    TABLES = {'APASS':'II/336/apass9',
+              'SDSS' :'V/147/sdss12',
+              'PanSTARRS' : 'II/349/ps1',
+              'SkyMapper' : 'II/358/smss'
+              }
+
+    tbname = TABLES.get(cat_name, None)
+    kwargs = {'radius':'0.33 deg'}
+    kwargs['catalog'] = cat_name
+
+    try:
+        v=Vizier(columns=['all']) # Skymapper by default does not report the error columns
+        v.ROW_LIMIT=-1
+        query = v.query_region(avgCoord, **kwargs)
+    except VOSError:
+        raise AstrosourceException("Could not find RA {} Dec {} in {}".format(avgCoord.ra.value,avgCoord.dec.value, cat_name))
+
+    if query.keys():
+        resp = query[tbname]
+    else:
+        raise AstrosourceException("Could not find RA {} Dec {} in {}".format(avgCoord.ra.value,avgCoord.dec.value, cat_name))
 
 
+    logger.debug(f'Looking for sources in {cat_name}')
     if cat_name in ['APASS','PanSTARRS']:
         radecname = {'ra' :'RAJ2000', 'dec': 'DEJ2000'}
     elif cat_name == 'SDSS':
         radecname = {'ra' :'RA_ICRS', 'dec': 'DE_ICRS'}
+    elif cat_name == 'SkyMapper':
+        radecname = {'ra' :'RAICRS', 'dec': 'DEICRS'}
     else:
         radecname = {'ra' :'raj2000', 'dec': 'dej2000'}
+
+    # Filter out bad data from catalogues
+    if cat_name == 'PanSTARRS':
+        resp = resp[where((resp['Qual'] == 52) | (resp['Qual'] == 60) | (resp['Qual'] == 61))]
+    elif cat_name == 'SDSS':
+        resp = resp[resp['Q'] == 3]
+    elif cat_name == 'SkyMapper':
+        resp = resp[resp['flags'] == 0]
+
+    data.cat_name = cat_name
     data.ra = array(resp[radecname['ra']].data)
     data.dec = array(resp[radecname['dec']].data)
 
@@ -352,15 +372,20 @@ def find_comparisons_calibrated(filterCode, paths=None, max_magerr=0.05, stdMult
     FILTERS = {
                 'B' : {'APASS' : {'filter' : 'Bmag', 'error' : 'e_Bmag'}},
                 'V' : {'APASS' : {'filter' : 'Vmag', 'error' : 'e_Vmag'}},
-                'up' : {'SDSS' : {'filter' : 'u_psf', 'error' : 'e_u_psf'},
+                'up' : {'SDSS' : {'filter' : 'umag', 'error' : 'e_umag'},
+                        'SkyMapper' : {'filter' : 'uPSF', 'error' : 'e_uPSF'},
                         'PanSTARRS': {'filter' : 'umag', 'error' : 'e_umag'}},
-                'gp' : {'SDSS' : {'filter' : 'g_psf', 'error' : 'e_g_psf'},
+                'gp' : {'SDSS' : {'filter' : 'gmag', 'error' : 'e_mag'},
+                        'SkyMapper' : {'filter' : 'gPSF', 'error' : 'e_gPSF'},
                         'PanSTARRS': {'filter' : 'gmag', 'error' : 'e_gmag'}},
-                'rp' : {'SDSS' : {'filter' : 'r_psf', 'error' : 'e_r_psf'},
+                'rp' : {'SDSS' : {'filter' : 'rmag', 'error' : 'e_rmag'},
+                        'SkyMapper' : {'filter' : 'rPSF', 'error' : 'e_rPSF'},
                         'PanSTARRS': {'filter' : 'rmag', 'error' : 'e_rmag'}},
                 'ip' : {'SDSS' : {'filter' : 'imag', 'error' : 'e_imag'},
+                        'SkyMapper' : {'filter' : 'iPSF', 'error' : 'e_iPSF'},
                         'PanSTARRS': {'filter' : 'imag', 'error' : 'e_imag'}},
-                'zs' : {'SDSS' : {'filter' : 'z_psf', 'error' : 'e_z_psf'},
+                'zs' : {'SDSS' : {'filter' : 'zmag', 'error' : 'e_zmag'},
+                        'SkyMapper' : {'filter' : 'zPSF', 'error' : 'e_zPSF'},
                         'PanSTARRS': {'filter' : 'zmag', 'error' : 'e_zmag'}},
                 }
 
@@ -369,8 +394,7 @@ def find_comparisons_calibrated(filterCode, paths=None, max_magerr=0.05, stdMult
     if not calibPath.exists():
         os.makedirs(calibPath)
 
-    Vizier.ROW_LIMIT = -1
-    max_sep=1.0 * arcsecond
+    #Vizier.ROW_LIMIT = -1
 
     # Get List of Files Used
     fileList=[]
@@ -383,13 +407,13 @@ def find_comparisons_calibrated(filterCode, paths=None, max_magerr=0.05, stdMult
     compFile = genfromtxt(parentPath / 'stdComps.csv', dtype=float, delimiter=',')
     logger.debug(compFile.shape[0])
 
-    if compFile.shape[0] == 13:
+    if compFile.shape[0] == 13 and compFile.size == 13:
         compCoords=SkyCoord(ra=compFile[0]*degree, dec=compFile[1]*degree)
     else:
         compCoords=SkyCoord(ra=compFile[:,0]*degree, dec=compFile[:,1]*degree)
 
     # Get Average RA and Dec from file
-    if compFile.shape[0] == 13:
+    if compFile.shape[0] == 13 and compFile.size == 13:
         logger.debug(compFile[0])
         logger.debug(compFile[1])
         avgCoord=SkyCoord(ra=(compFile[0])*degree, dec=(compFile[1]*degree))
@@ -408,8 +432,14 @@ def find_comparisons_calibrated(filterCode, paths=None, max_magerr=0.05, stdMult
     for cat_name, opt in catalogues.items():
         try:
             coords = catalogue_call(avgCoord, opt, cat_name)
-        except AstrosourceException:
-            pass
+            if coords.cat_name == 'PanSTARRS' or coords.cat_name == 'APASS':
+                max_sep=2.5 * arcsecond
+            else:
+                max_sep=1.5 * arcsecond
+
+
+        except AstrosourceException as e:
+            logger.debug(e)
 
     if not coords:
         raise AstrosourceException(f"Could not find coordinate match in any catalogues for {filterCode}")
@@ -420,24 +450,26 @@ def find_comparisons_calibrated(filterCode, paths=None, max_magerr=0.05, stdMult
     #Get calib mags for least variable IDENTIFIED stars.... not the actual stars in compUsed!! Brighter, less variable stars may be too bright for calibration!
     #So the stars that will be used to calibrate the frames to get the OTHER stars.
     calibStands=[]
-    if compFile.shape[0] ==13:
+
+    if compFile.shape[0] ==13 and compFile.size ==13:
         lenloop=1
     else:
         lenloop=len(compFile[:,0])
+
     for q in range(lenloop):
-        if compFile.shape[0] ==13:
+        if compFile.shape[0] ==13 and compFile.size ==13:
             compCoord=SkyCoord(ra=compFile[0]*degree, dec=compFile[1]*degree)
         else:
             compCoord=SkyCoord(ra=compFile[q][0]*degree, dec=compFile[q][1]*degree)
         idxcomp,d2dcomp,d3dcomp=compCoord.match_to_catalog_sky(catCoords)
-
-        if d2dcomp *arcsecond < max_sep*arcsecond:
+        if d2dcomp < max_sep:
             if not isnan(coords.mag[idxcomp]):
-
-                if compFile.shape[0] ==13:
+                if compFile.shape[0] ==13 and compFile.size ==13:
                     calibStands.append([compFile[0],compFile[1],compFile[2],coords.mag[idxcomp],coords.emag[idxcomp]])
                 else:
                     calibStands.append([compFile[q][0],compFile[q][1],compFile[q][2],coords.mag[idxcomp],coords.emag[idxcomp]])
+    logger.info('Calibration Stars Identified below')
+    logger.info(calibStands)
 
     # Get the set of least variable stars to use as a comparison to calibrate the files (to eventually get the *ACTUAL* standards
     #logger.debug(asarray(calibStands).shape[0])
@@ -448,10 +480,6 @@ def find_comparisons_calibrated(filterCode, paths=None, max_magerr=0.05, stdMult
 
     varimin=(min(asarray(calibStands)[:,2])) * variabilityMultiplier
 
-    logger.debug("varimin")
-    #logger.debug(asarray(calibStands)[:,2])
-    logger.debug(varimin)
-
     calibStandsReject=[]
     for q in range(len(asarray(calibStands)[:,0])):
         if calibStands[q][2] > varimin:
